@@ -22,7 +22,8 @@ function PMA_getNewDatabase($sql, $databases)
     $db = '';
     // loop through all the databases
     foreach ($databases as $database) {
-        if (strpos($sql, $database['SCHEMA_NAME']) !== false) {
+        if (/*overload*/mb_strpos($sql, $database['SCHEMA_NAME']) !== false
+        ) {
             $db = $database['SCHEMA_NAME'];
             break;
         }
@@ -33,7 +34,7 @@ function PMA_getNewDatabase($sql, $databases)
 /**
  * Get the table name in a sql query
  * If there are several tables in the SQL query,
- * first table wil lreturn
+ * first table will return
  *
  * @param string $sql    SQL query
  * @param array  $tables array of names in current database
@@ -46,7 +47,7 @@ function PMA_getTableNameBySQL($sql, $tables)
 
     // loop through all the tables in the database
     foreach ($tables as $tbl) {
-        if (strpos($sql, $tbl)) {
+        if (/*overload*/mb_strpos($sql, $tbl)) {
             $table .= ' ' . $tbl;
         }
     }
@@ -100,6 +101,7 @@ function PMA_getTableHtmlForMultipleQueries(
     do {
         $analyzed_sql = array();
         $is_affected = false;
+        $showtable = array();
 
         $result = $GLOBALS['dbi']->storeResult();
         $fields_meta = ($result !== false)
@@ -110,7 +112,10 @@ function PMA_getTableHtmlForMultipleQueries(
         // Initialize needed params related to each query in multiquery statement
         if (isset($sql_data['valid_sql'][$sql_no])) {
             // 'Use' query can change the database
-            if (stripos($sql_data['valid_sql'][$sql_no], "use ")) {
+            if (/*overload*/mb_stripos(
+                $sql_data['valid_sql'][$sql_no],
+                "use "
+            )) {
                 $db = PMA_getNewDatabase(
                     $sql_data['valid_sql'][$sql_no],
                     $databases_array
@@ -130,7 +135,7 @@ function PMA_getTableHtmlForMultipleQueries(
 
             $unlim_num_rows = PMA_Table::countRecords($db, $table, true);
             $showtable = PMA_Table::sGetStatusInfo($db, $table, null, true);
-            $url_query = PMA_URL_getCommon($db, $table);
+            $url_query = PMA_URL_getCommon(array('db' => $db, 'table' => $table));
 
             // Handle remembered sorting order, only for single table query
             if ($GLOBALS['cfg']['RememberSorting']
@@ -159,7 +164,6 @@ function PMA_getTableHtmlForMultipleQueries(
                     . $_SESSION['tmpval']['pos']
                     . ', ' . $_SESSION['tmpval']['max_rows'] . " ";
                 $sql_data['valid_sql'][$sql_no] = PMA_getSqlWithLimitClause(
-                    $sql_data['valid_sql'][$sql_no],
                     $analyzed_sql,
                     $sql_limit_to_append
                 );
@@ -195,7 +199,7 @@ function PMA_getTableHtmlForMultipleQueries(
             continue;
         }
 
-        // With multiple results, operations are limied
+        // With multiple results, operations are limited
         $disp_mode = 'nnnn000000';
         $is_limited_display = true;
 
@@ -263,13 +267,12 @@ function PMA_handleSortOrder(
 /**
  * Append limit clause to SQL query
  *
- * @param string $full_sql_query      SQL query
  * @param array  $analyzed_sql        the analyzed query
  * @param string $sql_limit_to_append clause to append
  *
  * @return string limit clause appended SQL query
  */
-function PMA_getSqlWithLimitClause($full_sql_query, $analyzed_sql,
+function PMA_getSqlWithLimitClause($analyzed_sql,
     $sql_limit_to_append
 ) {
     return $analyzed_sql[0]['section_before_limit'] . "\n"
@@ -289,7 +292,7 @@ function PMA_getColumnNameInColumnDropSql($sql)
     $tmpArray1 = explode('DROP', $sql);
     $str_to_check = trim($tmpArray1[1]);
 
-    if (stripos($str_to_check, 'COLUMN') !== false) {
+    if (/*overload*/mb_stripos($str_to_check, 'COLUMN') !== false) {
         $tmpArray2 = explode('COLUMN', $str_to_check);
         $str_to_check = trim($tmpArray2[1]);
     }
@@ -390,7 +393,7 @@ function PMA_getHtmlForRelationalColumnDropdown($db, $table, $column, $curr_valu
             . '</span>'
             . '<a href="browse_foreigners.php'
             . PMA_URL_getCommon($_url_params) . '"'
-            . ' target="_blank" class="browse_foreign" ' . '>'
+            . 'class="ajax browse_foreign" ' . '>'
             . __('Browse foreign values')
             . '</a>';
     } else {
@@ -424,7 +427,6 @@ function PMA_getHtmlForPrintViewHeader($db, $sql_query, $num_rows)
     if (isset($_REQUEST['printview']) && $_REQUEST['printview'] == '1') {
         PMA_Util::checkParameters(array('db', 'sql_query'));
         $header->enablePrintView();
-        $hostname = '';
         if ( $GLOBALS['cfg']['Server']['verbose']) {
             $hostname =  $GLOBALS['cfg']['Server']['verbose'];
         } else {
@@ -477,7 +479,9 @@ function PMA_getHtmlForProfilingChart($url_query, $db, $profiling_results)
 {
     if (isset($profiling_results)) {
         $pma_token = $_SESSION[' PMA_token '];
-        $url_query = (isset($url_query) ? $url_query : PMA_URL_getCommon($db));
+        $url_query = isset($url_query)
+            ? $url_query
+            : PMA_URL_getCommon(array('db' => $db));
 
         $profiling_table = '';
         $profiling_table .= '<fieldset><legend>' . __('Profiling')
@@ -754,7 +758,6 @@ function PMA_getHtmlForBookmark($disp_mode, $cfgBookmark, $sql_query, $db, $tabl
         && (! empty($cfgBookmark) && empty($_GET['id_bookmark']))
         && ! empty($sql_query)
     ) {
-        $html = "\n";
         $goto = 'sql.php'
             . PMA_URL_getCommon(
                 array(
@@ -768,10 +771,12 @@ function PMA_getHtmlForBookmark($disp_mode, $cfgBookmark, $sql_query, $db, $tabl
             isset($complete_query) ? $complete_query : $sql_query
         );
         $html = '<form action="sql.php" method="post"'
-            . ' onsubmit="return ! emptyFormElements(this,'
+            . ' onsubmit="return ! emptyCheckTheField(this,'
             . '\'bkm_fields[bkm_label]\');"'
             . ' id="bookmarkQueryForm">';
         $html .= PMA_URL_getHiddenInputs();
+        $html .= '<input type="hidden" name="db"'
+            . ' value="' . htmlspecialchars($db) . '" />';
         $html .= '<input type="hidden" name="goto" value="' . $goto . '" />';
         $html .= '<input type="hidden" name="bkm_fields[bkm_database]"'
             . ' value="' . htmlspecialchars($db) . '" />';
@@ -906,7 +911,7 @@ function PMA_isJustBrowsing($analyzed_sql_results, $find_real_end)
 }
 
 /**
- * Function to check whether the reated transformation information shoul be deleted
+ * Function to check whether the related transformation information should be deleted
  *
  * @param array $analyzed_sql_results the analyzed query and other variables set
  *                                    after analyzing the query
@@ -951,18 +956,29 @@ function PMA_hasNoRightsToDropDatabase($analyzed_sql_results,
 }
 
 /**
- * Function to set the column order
+ * Function to set a column property
  *
- * @param PMA_Table $pmatable PMA_Table instance
+ * @param PMA_Table $pmatable      PMA_Table instance
+ * @param string    $request_index col_order|col_visib
  *
  * @return boolean $retval
  */
-function PMA_setColumnOrder($pmatable)
+function PMA_setColumnProperty($pmatable, $request_index)
 {
-    $col_order = explode(',', $_REQUEST['col_order']);
+    $property_value = explode(',', $_REQUEST[$request_index]);
+    switch($request_index) {
+    case 'col_order':
+        $property_to_set = PMA_Table::PROP_COLUMN_ORDER;
+        break;
+    case 'col_visib':
+        $property_to_set = PMA_Table::PROP_COLUMN_VISIB;
+        break;
+    default:
+        $property_to_set = '';
+    }
     $retval = $pmatable->setUiProp(
-        PMA_Table::PROP_COLUMN_ORDER,
-        $col_order,
+        $property_to_set,
+        $property_value,
         $_REQUEST['table_create_time']
     );
     if (gettype($retval) != 'boolean') {
@@ -975,29 +991,6 @@ function PMA_setColumnOrder($pmatable)
     return $retval;
 }
 
-/**
- * Function to set the column visibility
- *
- * @param PMA_Table $pmatable PMA_Table instance
- *
- * @return boolean $retval
- */
-function PMA_setColumnVisibility($pmatable)
-{
-    $col_visib = explode(',', $_REQUEST['col_visib']);
-    $retval = $pmatable->setUiProp(
-        PMA_Table::PROP_COLUMN_VISIB, $col_visib,
-        $_REQUEST['table_create_time']
-    );
-    if (gettype($retval) != 'boolean') {
-        $response = PMA_Response::getInstance();
-        $response->isSuccess(false);
-        $response->addJSON('message', $retval->getString());
-        exit;
-    }
-    return $retval;
-}
-
 /**
  * Function to check the request for setting the column order or visibility
  *
@@ -1013,12 +1006,12 @@ function PMA_setColumnOrderOrVisibility($table, $db)
 
     // set column order
     if (isset($_REQUEST['col_order'])) {
-        $retval = PMA_setColumnOrder($pmatable);
+        $retval = PMA_setColumnProperty($pmatable, 'col_order');
     }
 
     // set column visibility
     if ($retval === true && isset($_REQUEST['col_visib'])) {
-        $retval = PMA_setColumnVisibility($pmatable);
+        $retval = PMA_setColumnProperty($pmatable, 'col_visib');
     }
 
     $response = PMA_Response::getInstance();
@@ -1085,8 +1078,8 @@ function PMA_findRealEndOfRows($db, $table)
 /**
  * Function to get values for the relational columns
  *
- * @param String $db            the current database
- * @param String $table         the current table
+ * @param String $db    the current database
+ * @param String $table the current table
  *
  * @return void
  */
@@ -1138,47 +1131,20 @@ function PMA_getEnumOrSetValues($db, $table, $columnType)
 /**
  * Function to append the limit clause
  *
- * @param String $full_sql_query full sql query
- * @param array  $analyzed_sql   analyzed sql query
- * @param String $display_query  display query
+ * @param array $analyzed_sql analyzed sql query
  *
  * @return array
  */
-function PMA_appendLimitClause($full_sql_query, $analyzed_sql, $display_query)
+function PMA_appendLimitClause($analyzed_sql)
 {
     $sql_limit_to_append = ' LIMIT ' . $_SESSION['tmpval']['pos']
         . ', ' . $_SESSION['tmpval']['max_rows'] . " ";
     $full_sql_query = PMA_getSqlWithLimitClause(
-        $full_sql_query,
         $analyzed_sql,
         $sql_limit_to_append
     );
 
-    /**
-     * @todo pretty printing of this modified query
-     */
-    if ($display_query) {
-        // if the analysis of the original query revealed that we found
-        // a section_after_limit, we now have to analyze $display_query
-        // to display it correctly
-
-        if (! empty($analyzed_sql[0]['section_after_limit'])
-            && trim($analyzed_sql[0]['section_after_limit']) != ';'
-        ) {
-            $analyzed_display_query = PMA_SQP_analyze(
-                PMA_SQP_parse($display_query)
-            );
-            $display_query  = $analyzed_display_query[0]['section_before_limit']
-                . "\n" . $sql_limit_to_append
-                . $analyzed_display_query[0]['section_after_limit'];
-        }
-    }
-
-    return array($sql_limit_to_append, $full_sql_query, isset(
-        $analyzed_display_query)
-        ? $analyzed_display_query : null,
-        isset($display_query) ? $display_query : null
-    );
+    return array($sql_limit_to_append, $full_sql_query);
 }
 
 /**
@@ -1210,7 +1176,39 @@ function PMA_getDefaultSqlQueryForBrowse($db, $table)
         );
         $sql_query = $book_sql_query;
     } else {
-        $sql_query = 'SELECT * FROM ' . PMA_Util::backquote($table);
+
+        $defaultOrderByClause = '';
+
+        if (isset($GLOBALS['cfg']['TablePrimaryKeyOrder'])
+            && ($GLOBALS['cfg']['TablePrimaryKeyOrder'] !== 'NONE')
+        ) {
+
+            $primaryKey     = null;
+            $primary        = PMA_Index::getPrimary($table, $db);
+
+            if ($primary !== false) {
+
+                $primarycols    = $primary->getColumns();
+
+                foreach ($primarycols as $col) {
+                    $primaryKey = $col->getName();
+                    break;
+                }
+
+                if ($primaryKey != null) {
+                    $defaultOrderByClause = ' ORDER BY '
+                                          . PMA_Util::backquote($table) . '.'
+                                          . PMA_Util::backquote($primaryKey) . ' '
+                                          . $GLOBALS['cfg']['TablePrimaryKeyOrder'];
+                }
+
+            }
+
+        }
+
+        $sql_query = 'SELECT * FROM ' . PMA_Util::backquote($table)
+            . $defaultOrderByClause;
+
     }
     unset($book_sql_query);
 
@@ -1294,15 +1292,6 @@ function PMA_executeQueryAndStoreResults($full_sql_query)
 
     $GLOBALS['querytime'] = $querytime_after - $querytime_before;
 
-    // If a stored procedure was called, there may be more results that are
-    // queued up and waiting to be flushed from the buffer. So let's do that.
-    do {
-        $GLOBALS['dbi']->storeResult();
-        if (! $GLOBALS['dbi']->moreResults()) {
-            break;
-        }
-    } while ($GLOBALS['dbi']->nextResult());
-
     return $result;
 }
 
@@ -1339,7 +1328,7 @@ function PMA_hasCurrentDbChanged($db)
     // Checks if the current database has changed
     // This could happen if the user sends a query like "USE `database`;"
     $reload = 0;
-    if (strlen($db)) {
+    if (/*overload*/mb_strlen($db)) {
         $current_db = $GLOBALS['dbi']->fetchValue('SELECT DATABASE()');
         // $current_db is false, except when a USE statement was sent
         if ($current_db != false && $db !== $current_db) {
@@ -1366,17 +1355,17 @@ function PMA_cleanupRelations($db, $table, $dropped_column, $purge, $extra_data)
     include_once 'libraries/relation_cleanup.lib.php';
 
     if (isset($purge) && $purge == 1) {
-        if (strlen($table) && strlen($db)) {
+        if (/*overload*/mb_strlen($table) && /*overload*/mb_strlen($db)) {
             PMA_relationsCleanupTable($db, $table);
-        } elseif (strlen($db)) {
+        } elseif (/*overload*/mb_strlen($db)) {
             PMA_relationsCleanupDatabase($db);
         }
     }
 
     if (isset($dropped_column)
         && !empty($dropped_column)
-        && strlen($db)
-        && strlen($table)
+        && /*overload*/mb_strlen($db)
+        && /*overload*/mb_strlen($table)
     ) {
         PMA_relationsCleanupColumn($db, $table, $dropped_column);
         // to refresh the list of indexes (Ajax mode)
@@ -1428,7 +1417,7 @@ function PMA_countQueryResults(
                 false
             );
             /**
-             * @todo Can we know at this point that this is InnoDB, 
+             * @todo Can we know at this point that this is InnoDB,
              *       (in this case there would be no need for getting
              *       an exact count)?
              */
@@ -1437,7 +1426,7 @@ function PMA_countQueryResults(
                 // is less than MaxExactCount
                 /**
                  * @todo In countRecords(), MaxExactCount is also verified,
-                 *       so can we avoid checking it twice? 
+                 *       so can we avoid checking it twice?
                  */
                 $unlim_num_rows = PMA_Table::countRecords(
                     $db,
@@ -1550,8 +1539,9 @@ function PMA_executeTheQuery($analyzed_sql_results, $full_sql_query, $is_gotofil
         // If there are no errors and bookmarklabel was given,
         // store the query as a bookmark
         if (! empty($_POST['bkm_label']) && ! empty($sql_query_for_bookmark)) {
+            $cfgBookmark = PMA_Bookmark_getParams();
             PMA_storeTheQueryAsBookmark(
-                $db, $GLOBALS['cfg']['Bookmark']['user'],
+                $db, $cfgBookmark['user'],
                 $sql_query_for_bookmark, $_POST['bkm_label'],
                 isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
             );
@@ -1593,8 +1583,7 @@ function PMA_executeTheQuery($analyzed_sql_results, $full_sql_query, $is_gotofil
     }
 
     return array($result, $num_rows, $unlim_num_rows,
-        isset($profiling_results) ? $profiling_results : null,
-        isset($justBrowsing) ? $justBrowsing : null, $extra_data
+        isset($profiling_results) ? $profiling_results : null, $extra_data
     );
 }
 /**
@@ -1610,7 +1599,11 @@ function PMA_deleteTransformationInfo($db, $table, $analyzed_sql)
 {
     include_once 'libraries/transformations.lib.php';
     if ($analyzed_sql[0]['querytype'] == 'ALTER') {
-        if (stripos($analyzed_sql[0]['unsorted_query'], 'DROP') !== false) {
+        $posDrop = /*overload*/mb_stripos(
+            $analyzed_sql[0]['unsorted_query'],
+            'DROP'
+        );
+        if ($posDrop !== false) {
             $drop_column = PMA_getColumnNameInColumnDropSql(
                 $analyzed_sql[0]['unsorted_query']
             );
@@ -1690,6 +1683,11 @@ function PMA_getMessageForNoRowsReturned($message_to_show, $analyzed_sql_results
         $message->addMessage($_querytime);
     }
 
+    // In case of ROLLBACK, notify the user.
+    if (isset($_REQUEST['rollback_query'])) {
+        $message->addMessage(__('[ROLLBACK occurred.]'));
+    }
+
     return $message;
 }
 
@@ -1746,7 +1744,7 @@ function PMA_sendAjaxResponseForNoResultsReturned($message, $analyzed_sql,
  * 1-> When browsing an empty table
  * 2-> When executing a query on a non empty table which returns zero results
  * 3-> When executing a query on an empty table
- * 4-> When executing an INSERT, UPDATE, DEDETE query from the SQL  tab
+ * 4-> When executing an INSERT, UPDATE, DELETE query from the SQL tab
  * 5-> When deleting a row from BROWSE tab
  * 6-> When searching using the SEARCH tab which returns zero results
  * 7-> When changing the structure of the table except change operation
@@ -1794,6 +1792,10 @@ function PMA_sendQueryResponseForNoResultsReturned($analyzed_sql_results, $db,
 function PMA_sendResponseForGridEdit($result)
 {
     $row = $GLOBALS['dbi']->fetchRow($result);
+    $field_flags = $GLOBALS['dbi']->fieldFlags($result, 0);
+    if (stristr($field_flags, PMA_DisplayResults::BINARY_FIELD)) {
+        $row[0] = bin2hex($row[0]);
+    }
     $response = PMA_Response::getInstance();
     $response->addJSON('value', $row[0]);
     exit;
@@ -1845,7 +1847,9 @@ function PMA_getHtmlForSqlQueryResults($previous_update_query_html,
 function PMA_getBookmarkCreatedMessage()
 {
     if (isset($_GET['label'])) {
-        $bookmark_created_msg = PMA_message::success(__('Bookmark %s has been created.'));
+        $bookmark_created_msg = PMA_message::success(
+            __('Bookmark %s has been created.')
+        );
         $bookmark_created_msg->addParam($_GET['label']);
     } else {
         $bookmark_created_msg = null;
@@ -1880,15 +1884,61 @@ function PMA_getHtmlForSqlQueryResultsTable($sql_data, $displayResultsObject, $d
     $analyzed_sql_results
 ) {
     $printview = isset($_REQUEST['printview']) ? $_REQUEST['printview'] : null;
-    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)
-        || $analyzed_sql_results['is_procedure']
-    ) {
+    $table_html = '';
+    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)) {
         $_SESSION['is_multi_query'] = true;
-        $table_html = PMA_getTableHtmlForMultipleQueries(
+        $table_html .= PMA_getTableHtmlForMultipleQueries(
             $displayResultsObject, $db, $sql_data, $goto,
             $pmaThemeImage, $printview, $url_query,
             $disp_mode, $sql_limit_to_append, $editable
         );
+    } elseif ($analyzed_sql_results['is_procedure']) {
+
+        do {
+            if (! isset($result)) {
+                $result = $GLOBALS['dbi']->storeResult();
+            }
+            $num_rows = $GLOBALS['dbi']->numRows($result);
+
+            if ($result !== false && $num_rows > 0) {
+
+                $fields_meta = $GLOBALS['dbi']->getFieldsMeta($result);
+                $fields_cnt  = count($fields_meta);
+
+                $displayResultsObject->setProperties(
+                    $num_rows,
+                    $fields_meta,
+                    $analyzed_sql_results['is_count'],
+                    $analyzed_sql_results['is_export'],
+                    $analyzed_sql_results['is_func'],
+                    $analyzed_sql_results['is_analyse'],
+                    $num_rows,
+                    $fields_cnt,
+                    $GLOBALS['querytime'],
+                    $pmaThemeImage,
+                    $GLOBALS['text_dir'],
+                    $analyzed_sql_results['is_maint'],
+                    $analyzed_sql_results['is_explain'],
+                    $analyzed_sql_results['is_show'],
+                    $showtable,
+                    $printview,
+                    $url_query,
+                    $editable
+                );
+
+                $disp_mode = 'nnnn110111'; // uneditable
+                $table_html .= $displayResultsObject->getTable(
+                    $result,
+                    $disp_mode,
+                    $analyzed_sql_results['analyzed_sql']
+                );
+            }
+
+            $GLOBALS['dbi']->freeResult($result);
+            unset($result);
+
+        } while ($GLOBALS['dbi']->moreResults() && $GLOBALS['dbi']->nextResult());
+
     } else {
         if (isset($result) && $result) {
             $fields_meta = $GLOBALS['dbi']->getFieldsMeta($result);
@@ -1905,7 +1955,7 @@ function PMA_getHtmlForSqlQueryResultsTable($sql_data, $displayResultsObject, $d
             $editable
         );
 
-        $table_html = $displayResultsObject->getTable(
+        $table_html .= $displayResultsObject->getTable(
             $result, $disp_mode, $analyzed_sql_results['analyzed_sql']
         );
         $GLOBALS['dbi']->freeResult($result);
@@ -1943,14 +1993,13 @@ function PMA_getHtmlForPreviousUpdateQuery($disp_query, $showSql, $sql_data,
 /**
  * To get the message if a column index is missing. If not will return null
  *
- * @param string  $table     current table
- * @param string  $db        current database
- * @param boolean $editable  whether the results table can be editable or not
- * @param string  $disp_mode display mode
+ * @param string  $table    current table
+ * @param string  $db       current database
+ * @param boolean $editable whether the results table can be editable or not
  *
  * @return PMA_message $message
  */
-function PMA_getMessageIfMissingColumnIndex($table, $db, $editable, $disp_mode)
+function PMA_getMessageIfMissingColumnIndex($table, $db, $editable)
 {
     if (!empty($table) && ($GLOBALS['dbi']->isSystemSchema($db) || !$editable)) {
         $missing_unique_column_msg = PMA_message::notice(
@@ -1970,25 +2019,25 @@ function PMA_getMessageIfMissingColumnIndex($table, $db, $editable, $disp_mode)
 /**
  * Function to get html to display problems in indexes
  *
- * @param string $query_type query type
- * @param bool   $selected   whether check table, optimize table, analyze
- *                            table or repair table has been selected with
- *                            respect to the selected tables from the
- *                            database structure page.
- * @param string $db         current database
+ * @param string     $query_type     query type
+ * @param array|null $selectedTables array of table names selected from the
+ *                                   database structure page, for an action
+ *                                   like check table, optimize table,
+ *                                   analyze table or repair table
+ * @param string     $db             current database
  *
  * @return string
  */
-function PMA_getHtmlForIndexesProblems($query_type, $selected, $db)
+function PMA_getHtmlForIndexesProblems($query_type, $selectedTables, $db)
 {
     // BEGIN INDEX CHECK See if indexes should be checked.
     if (isset($query_type)
         && $query_type == 'check_tbl'
-        && isset($selected)
-        && is_array($selected)
+        && isset($selectedTables)
+        && is_array($selectedTables)
     ) {
         $indexes_problems_html = '';
-        foreach ($selected as $tbl_name) {
+        foreach ($selectedTables as $tbl_name) {
             $check = PMA_Index::findDuplicates($tbl_name, $db);
             if (! empty($check)) {
                 $indexes_problems_html .= sprintf(
@@ -2024,39 +2073,38 @@ function PMA_getHtmlForPrintButton()
 /**
  * Function to display results when the executed query returns non empty results
  *
- * @param array  $result               executed query results
- * @param bool   $justBrowsing         whether just browsing or not
- * @param array  $analyzed_sql_results analysed sql results
- * @param string $db                   current database
- * @param string $table                current table
- * @param string $disp_mode            display mode
- * @param string $message              message to show
- * @param array  $sql_data             sql data
- * @param object $displayResultsObject Instance of DisplyResults.class
- * @param string $goto                 goto page url
- * @param string $pmaThemeImage        uri of the theme image
- * @param string $sql_limit_to_append  sql limit to append
- * @param int    $unlim_num_rows       unlimited number of rows
- * @param int    $num_rows             number of rows
- * @param string $full_sql_query       full sql query
- * @param string $disp_query           display query
- * @param string $disp_message         display message
- * @param array  $profiling_results    profiling results
- * @param string $query_type           query type
- * @param bool   $selected             whether check table, optimize table, analyze
- *                                     table or repair table has been selected with
- *                                     respect to the selected tables from the
- *                                     database structure page.
- * @param string $sql_query            sql query
- * @param string $complete_query       complete sql query
+ * @param array      $result               executed query results
+ * @param array      $analyzed_sql_results analysed sql results
+ * @param string     $db                   current database
+ * @param string     $table                current table
+ * @param string     $disp_mode            display mode
+ * @param string     $message              message to show
+ * @param array      $sql_data             sql data
+ * @param object     $displayResultsObject Instance of DisplayResults.class
+ * @param string     $goto                 goto page url
+ * @param string     $pmaThemeImage        uri of the theme image
+ * @param string     $sql_limit_to_append  sql limit to append
+ * @param int        $unlim_num_rows       unlimited number of rows
+ * @param int        $num_rows             number of rows
+ * @param string     $full_sql_query       full sql query
+ * @param string     $disp_query           display query
+ * @param string     $disp_message         display message
+ * @param array      $profiling_results    profiling results
+ * @param string     $query_type           query type
+ * @param array|null $selectedTables       array of table names selected from
+ *                                         the database structure page, for an
+ *                                         action like check table, optimize
+ *                                         table, analyze table or repair table
+ * @param string     $sql_query            sql query
+ * @param string     $complete_query       complete sql query
  *
  * @return void
  */
-function PMA_sendQueryResponseForResultsReturned($result, $justBrowsing,
+function PMA_sendQueryResponseForResultsReturned($result,
     $analyzed_sql_results, $db, $table, $disp_mode, $message, $sql_data,
     $displayResultsObject, $goto, $pmaThemeImage, $sql_limit_to_append,
     $unlim_num_rows, $num_rows,  $full_sql_query, $disp_query,
-    $disp_message, $profiling_results, $query_type, $selected, $sql_query,
+    $disp_message, $profiling_results, $query_type, $selectedTables, $sql_query,
     $complete_query
 ) {
     // If we are retrieving the full value of a truncated field or the original
@@ -2156,7 +2204,7 @@ function PMA_sendQueryResponseForResultsReturned($result, $justBrowsing,
     );
 
     $missing_unique_column_msg = PMA_getMessageIfMissingColumnIndex(
-        $table, $db, $editable, $disp_mode
+        $table, $db, $editable
     );
 
     $bookmark_created_msg = PMA_getBookmarkCreatedMessage();
@@ -2170,16 +2218,17 @@ function PMA_sendQueryResponseForResultsReturned($result, $justBrowsing,
 
     $indexes_problems_html = PMA_getHtmlForIndexesProblems(
         isset($query_type) ? $query_type : null,
-        isset($selected) ? $selected : null, $db
+        isset($selectedTables) ? $selectedTables : null, $db
     );
 
-    if (isset($GLOBALS['cfg']['Bookmark'])) {
+    $cfgBookmark = PMA_Bookmark_getParams();
+    if ($cfgBookmark) {
         $bookmark_support_html = PMA_getHtmlForBookmark(
             $disp_mode,
-            $GLOBALS['cfg']['Bookmark'],
+            $cfgBookmark,
             $sql_query, $db, $table,
             isset($complete_query) ? $complete_query : $sql_query,
-            $GLOBALS['cfg']['Bookmark']['user']
+            $cfgBookmark['user']
         );
     } else {
         $bookmark_support_html = '';
@@ -2206,43 +2255,43 @@ function PMA_sendQueryResponseForResultsReturned($result, $justBrowsing,
 /**
  * Function to send response for both empty results and non empty results
  *
- * @param int    $num_rows             number of rows returned by the executed query
- * @param int    $unlim_num_rows       unlimited number of rows
- * @param bool   $is_affected          is affected
- * @param string $db                   current database
- * @param string $table                current table
- * @param string $message_to_show      message to show
- * @param array  $analyzed_sql_results analyzed Sql Results
- * @param object $displayResultsObject Instance of DisplayResult class
- * @param array  $extra_data           extra data
- * @param array  $result               executed query results
- * @param bool   $justBrowsing         whether just browsing or not
- * @param string $disp_mode            disply mode
- * @param object $message              message
- * @param array  $sql_data             sql data
- * @param string $goto                 goto page url
- * @param string $pmaThemeImage        uri of the PMA theme image
- * @param string $sql_limit_to_append  sql limit to append
- * @param string $full_sql_query       full sql query
- * @param string $disp_query           display query
- * @param string $disp_message         display message
- * @param array  $profiling_results    profiling results
- * @param string $query_type           query type
- * @param bool   $selected             whether check table, optimize table, analyze
- *                                     table or repair table has been selected with
- *                                     respect to the selected tables from the
- *                                     database structure page.
- * @param string $sql_query            sql query
- * @param string $complete_query       complete query
+ * @param int        $num_rows             number of rows returned by the
+ *                                         executed query
+ * @param int        $unlim_num_rows       unlimited number of rows
+ * @param bool       $is_affected          is affected
+ * @param string     $db                   current database
+ * @param string     $table                current table
+ * @param string     $message_to_show      message to show
+ * @param array      $analyzed_sql_results analyzed Sql Results
+ * @param object     $displayResultsObject Instance of DisplayResult class
+ * @param array      $extra_data           extra data
+ * @param array      $result               executed query results
+ * @param string     $disp_mode            display mode
+ * @param object     $message              message
+ * @param array      $sql_data             sql data
+ * @param string     $goto                 goto page url
+ * @param string     $pmaThemeImage        uri of the PMA theme image
+ * @param string     $sql_limit_to_append  sql limit to append
+ * @param string     $full_sql_query       full sql query
+ * @param string     $disp_query           display query
+ * @param string     $disp_message         display message
+ * @param array      $profiling_results    profiling results
+ * @param string     $query_type           query type
+ * @param array|null $selectedTables       array of table names selected from
+ *                                         the database structure page, for an
+ *                                         action like check table, optimize
+ *                                         table, analyze table or repair table
+ * @param string     $sql_query            sql query
+ * @param string     $complete_query       complete query
  *
  * @return void
  */
 function PMA_sendQueryResponse($num_rows, $unlim_num_rows, $is_affected,
     $db, $table, $message_to_show, $analyzed_sql_results, $displayResultsObject,
-    $extra_data, $result, $justBrowsing, $disp_mode,$message, $sql_data,
+    $extra_data, $result, $disp_mode,$message, $sql_data,
     $goto, $pmaThemeImage, $sql_limit_to_append, $full_sql_query,
-    $disp_query, $disp_message, $profiling_results, $query_type, $selected,
-    $sql_query, $complete_query
+    $disp_query, $disp_message, $profiling_results, $query_type,
+    $selectedTables, $sql_query, $complete_query
 ) {
     // No rows returned -> move back to the calling page
     if ((0 == $num_rows && 0 == $unlim_num_rows) || $is_affected) {
@@ -2255,7 +2304,7 @@ function PMA_sendQueryResponse($num_rows, $unlim_num_rows, $is_affected,
     } else {
         // At least one row is returned -> displays a table with results
         PMA_sendQueryResponseForResultsReturned(
-            isset($result) ? $result : null, $justBrowsing, $analyzed_sql_results,
+            isset($result) ? $result : null, $analyzed_sql_results,
             $db, $table, isset($disp_mode) ? $disp_mode : null,
             isset($message) ? $message : null, isset($sql_data) ? $sql_data : null,
             $displayResultsObject, $goto, $pmaThemeImage,
@@ -2264,7 +2313,7 @@ function PMA_sendQueryResponse($num_rows, $unlim_num_rows, $is_affected,
             isset($disp_query) ? $disp_query : null,
             isset($disp_message) ? $disp_message : null, $profiling_results,
             isset($query_type) ? $query_type : null,
-            isset($selected) ? $selected : null, $sql_query,
+            isset($selectedTables) ? $selectedTables : null, $sql_query,
             isset($complete_query) ? $complete_query : null
         );
     } // end rows returned
@@ -2291,10 +2340,10 @@ function PMA_sendQueryResponse($num_rows, $unlim_num_rows, $is_affected,
  * @param string     $disp_message           display message
  * @param string     $query_type             query type
  * @param string     $sql_query              sql query
- * @param bool|null  $selected               whether check table, optimize table,
- *                                           analyze table or repair table has been
- *                                           selected with respect to the selected
- *                                           tables from the database structure page
+ * @param array      $selectedTables         array of table names selected from the
+ *                                           database structure page, for an action
+ *                                           like check table, optimize table,
+ *                                           analyze table or repair table
  * @param string     $complete_query         complete query
  *
  * @return void
@@ -2303,7 +2352,7 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
     $is_gotofile, $db, $table, $find_real_end, $sql_query_for_bookmark,
     $extra_data, $is_affected, $message_to_show, $disp_mode, $message,
     $sql_data, $goto, $pmaThemeImage, $disp_query, $disp_message,
-    $query_type, $sql_query, $selected, $complete_query
+    $query_type, $sql_query, $selectedTables, $complete_query
 ) {
     // Include PMA_Index class for use in PMA_DisplayResults class
     include_once './libraries/Index.class.php';
@@ -2329,11 +2378,8 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
 
     // Do append a "LIMIT" clause?
     if (PMA_isAppendLimitClause($analyzed_sql_results)) {
-        list($sql_limit_to_append,
-            $full_sql_query, $analyzed_display_query, $display_query
-        ) = PMA_appendLimitClause(
-            $full_sql_query, $analyzed_sql_results['analyzed_sql'],
-            isset($display_query)
+        list($sql_limit_to_append, $full_sql_query) = PMA_appendLimitClause(
+            $analyzed_sql_results['analyzed_sql']
         );
     } else {
         $sql_limit_to_append = '';
@@ -2343,18 +2389,17 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
     $GLOBALS['dbi']->selectDb($db);
 
     // Execute the query
-    list($result, $num_rows, $unlim_num_rows, $profiling_results,
-        $justBrowsing, $extra_data
-    ) = PMA_executeTheQuery(
-        $analyzed_sql_results,
-        $full_sql_query,
-        $is_gotofile,
-        $db,
-        $table,
-        isset($find_real_end) ? $find_real_end : null,
-        isset($sql_query_for_bookmark) ? $sql_query_for_bookmark : null,
-        isset($extra_data) ? $extra_data : null
-    );
+    list($result, $num_rows, $unlim_num_rows, $profiling_results, $extra_data)
+        = PMA_executeTheQuery(
+            $analyzed_sql_results,
+            $full_sql_query,
+            $is_gotofile,
+            $db,
+            $table,
+            isset($find_real_end) ? $find_real_end : null,
+            isset($sql_query_for_bookmark) ? $sql_query_for_bookmark : null,
+            isset($extra_data) ? $extra_data : null
+        );
 
     PMA_sendQueryResponse(
         $num_rows,
@@ -2367,7 +2412,6 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
         $displayResultsObject,
         $extra_data,
         isset($result) ? $result : null,
-        $justBrowsing,
         isset($disp_mode) ? $disp_mode : null,
         isset($message) ? $message : null,
         isset($sql_data) ? $sql_data : null,
@@ -2379,7 +2423,7 @@ function PMA_executeQueryAndSendQueryResponse($analyzed_sql_results,
         isset($disp_message) ? $disp_message : null,
         $profiling_results,
         isset($query_type) ? $query_type : null,
-        isset($selected) ? $selected : null,
+        isset($selectedTables) ? $selectedTables : null,
         $sql_query,
         isset($complete_query) ? $complete_query : null
     );
